
.. _classic_examples_advection_2d_annulus:

Two-dimensional advection around an annulus
===========================================

On a mapped grid, as specified in `mapc2p.f` and `mapc2p.py`.

Quick regression test version:  regression_tests.py

* Checks sum of q values over left and right half, for two frames.
